Sample - Sphinx BlueBrain Theme

Skip to content

# Sample

This page includes samples of the expected output of the theme as well as the input used to generate it.

## Second level headings

Second level heading section content.

### Third level headings

Third level heading section content.

#### Fourth level headings

Fourth level heading section content.

##### Fifth level headings

Fifth level heading section content.

###### Sixth level headings

Sixth level heading section content.

    Sample
    ======

    This page includes samples of the expected output of the theme as well as
    the input used to generate it.

    Second level headings
    ---------------------

    Second level heading section content.

    Third level headings
    ~~~~~~~~~~~~~~~~~~~~

    Third level heading section content.

    Fourth level headings
    *********************

    Fourth level heading section content.

    Fifth level headings
    ^^^^^^^^^^^^^^^^^^^^

    Fifth level heading section content.

    Sixth level headings
    ++++++++++++++++++++

    Sixth level heading section content.

## Lists

### Unordered lists

- list item 1.

- list item 2.

  - nested list item 1.

  - nested list item 2.

    - double nested list item 1.

  - nested list item 3.

    Unordered lists
    ~~~~~~~~~~~~~~~

    * list item 1.
    * list item 2.

      * nested list item 1.
      * nested list item 2.

        * double nested list item 1.

      * nested list item 3.

### Ordered lists

1. List item 1.

2. List item 2.

   1. Nested list item 1.

   2. Nested list item 2.

      1. Double nested list item 1.

   3. Nested list item 3.

    Ordered lists
    ~~~~~~~~~~~~~

    #. List item 1.
    #. List item 2.

       #. Nested list item 1.
       #. Nested list item 2.

          #. Double nested list item 1.

       #. Nested list item 3.

### Definition lists

Definition list item 1

  Definition text for definition list item 1.

Definition list item 2

  Definition text for definition list item 2.

    Definition lists
    ~~~~~~~~~~~~~~~~

    Definition list item 1
       Definition text for definition list item 1.

    Definition list item 2
       Definition text for definition list item 2.

## Code

### Inline code

Here is some sample inline code: `if test: return True`.

Attention

If you need inline syntax highlighting, you must include a `docutils.conf` file in the same directory as your `conf.py` file.

The required content of the file is shown below (see https://stackoverflow.com/a/48655335):

    [restructuredtext parser]
    syntax_highlight = short

    Inline code
    ~~~~~~~~~~~

    .. role:: py3(code)
       :language: python3

    Here is some sample inline code: :py3:`if test: return True`.

### Code blocks

    1
    2
    def double(x):
       return 2 * x

    Code blocks
    ~~~~~~~~~~~

    .. code-block:: python3
       :linenos:
       :emphasize-lines: 2

       def double(x):
          return 2 * x

### Code tabs

Tabs can be used to show multiple examples without excessive space. The code can be entered directly or included from a file.

Python

    import sys

Ruby

    require sys

From file

    """This is a sample for the documentation."""

    def double(x):
        return 2.0 * x

    def halve(x):
        return 0.5 * x

    def list_of_three(x):
        return [x] * 3

    Code tabs
    ~~~~~~~~~

    Tabs can be used to show multiple examples without excessive space. The code
    can be entered directly or included from a file.

    .. tabgroup::

       .. codetab:: python Python

           import sys

       .. codetab:: ruby Ruby

           require sys

       .. literaltab:: sample.py From file
          :language: python3

## Tables

Table header column 1 | Column 2 | Column 3 | Col. 4 | C5 | C6
--- | --- | --- | --- | --- | ---
Row 1 data | 1.0 | 0.1234 | 0.001 | 10.0 | -1
Row 2 data | 1000.0 | -1.2345 | 5.01 | - | -

    Tables
    ------

    .. table::

       ======================== =========== ========== ======= ==== ===
       Table header column 1    Column 2    Column 3   Col. 4  C5   C6
       ======================== =========== ========== ======= ==== ===
       Row 1 data               1.0         0.1234     0.001   10.0 -1
       Row 2 data               1000.0      -1.2345    5.01    \-   \-
       ======================== =========== ========== ======= ==== ===

## Admonitions

### Built-in types

Attention

Attention

Caution

Caution

Danger

Danger

Error

Error

Hint

Hint

Important

Important

Note

Note

Tip

Tip

Warning

Warning

    Built-in types
    ~~~~~~~~~~~~~~

    .. attention::

       Attention

    .. caution::

       Caution

    .. danger::

       Danger

    .. error::

       Error

    .. hint::

       Hint

    .. important::

       Important

    .. note::

       Note

    .. tip::

       Tip

    .. warning::

       Warning

### Additional types

These types require you to add the class explicitly using `:class: classname`. Applicable classnames are shown in each admonition.

Abstract

- abstract

- summary

- tldr

Info

- info

- todo

Success

- success

- check

- done

Question

- question

- help

- faq

Failure

- failure

- fail

- missing

Bug

- bug

Example

- example

- snippet

Quote

- quote

- cite

    Additional types
    ~~~~~~~~~~~~~~~~

    These types require you to add the class explicitly using ``:class: classname``.
    Applicable classnames are shown in each admonition.

    .. admonition:: Abstract
       :class: abstract

       - abstract
       - summary
       - tldr

    .. admonition:: Info
       :class: info

       - info
       - todo

    .. admonition:: Success
       :class: success

       - success
       - check
       - done

    .. admonition:: Question
       :class: question

       - question
       - help
       - faq

    .. admonition:: Failure
       :class: failure

       - failure
       - fail
       - missing

    .. admonition:: Bug
       :class: bug

       - bug

    .. admonition:: Example
       :class: example

       - example
       - snippet

    .. admonition:: Quote
       :class: quote

       - quote
       - cite

## Miscellaneous

### Blockquotes

> Blockquote content.

    Blockquotes
    ~~~~~~~~~~~

       Blockquote content.

#### Nested blockquotes

> Blockquote content.

> > Nested blockquote content.

> > > Double nested blockquote content.

    Nested blockquotes
    ******************

       Blockquote content.

          Nested blockquote content.

             Double nested blockquote content.

### Horizontal rules

Here is some text before a horizontal rule.

Here is some text after a horizontal rule

    Horizontal rules
    ~~~~~~~~~~~~~~~~

    Here is some text before a horizontal rule.

    ----

    Here is some text after a horizontal rule

### Epigraphs

> This is an epigraph.

> —by an Author

    Epigraphs
    ~~~~~~~~~

    .. epigraph::

       This is an epigraph.

       -- by an Author

### Topics

Topic title

This is a topic

    Topics
    ~~~~~~

    .. topic:: Topic title

       This is a topic

### Sidebars

Here is some text that will flow around the sidebar that follows. If we have something interesting to say, we can put it in the sidebar.

    Sidebars
    ~~~~~~~~

    .. sidebar:: Sidebar title
       :class: admonition

       This is a sidebar

    Here is some text that will flow around the sidebar that follows.
    If we have something interesting to say, we can put it in the
    sidebar.

### Collapsible blocks

Details hidden by default

Here is some content that is hidden before opening.

Details shown by default

Here is some content that is shown by default

    Collapsible blocks
    ~~~~~~~~~~~~~~~~~~

    .. details:: Details hidden by default

       Here is some content that is hidden before opening.

    .. details:: Details shown by default
       :open:

       Here is some content that is shown by default

### IFrames

Embed existing HTML files (such as Doxygen output) in generated pages.

    IFrames
    ~~~~~~~

    Embed existing HTML files (such as Doxygen output) in generated pages.

    .. iframe:: index.html

## Source

regression.rst